# Py_colorgen

A python based random color generator(Hex, rgb, hsl)

## System Requirements

-   Python3

## Installation Instructions

```py
pip install Py_colorgen
```

## Options

```
  -h, --help                    show this help message and exit

  -r --rgb                      RGB random color combination and exit

  -s --hsl                      HSL random color combination and exit

  On default it generates Hex color combination and exit
```